#%% begin initialize mediawiki-1.13.2-noname-P1
###################################################################
export LANG=C
export PATH=/bin:/usr/bin:/sbin:/usr/sbin

if [ -r /tmp/SeTT_PX ]; then
  ROOT="`/usr/bin/cat /tmp/SeTT_PX`"
fi

APACI_DIR=$ROOT/opt/httpd
PG_DIR=$ROOT/opt/pgsql
WWW=$ROOT/home/www

if [ -f $ROOT/opt/htdocs/mediawiki ]; then
  /usr/bin/mv $ROOT/opt/htdocs/mediawiki $ROOT/opt/htdocs/mediawiki.bak
fi
(cd $ROOT/opt/htdocs; rm -f mediawiki; ln -sf mediawiki-1.13.2 mediawiki )


FQDN=`hostname -f`
if [ ".$FQDN" = "." ]; then
  FQDN=localhost
fi

/bin/su - postgres -c "sh $ROOT/opt/htdocs/mediawiki-1.13.2/custom/create_mediawiki-1.13_db83"
/usr/bin/cp $ROOT/opt/htdocs/mediawiki-1.13.2/custom/_htaccess $ROOT/opt/htdocs/mediawiki-1.13.2/.htaccess 

if [ ! -f $WWW/.postgresql/postgresql.crt ]; then
 /usr/bin/mkdir -p $WWW/.postgresql
 /usr/bin/cp $PG_DIR/data/server.crt $WWW/.postgresql/postgresql.crt
 /usr/bin/cp $PG_DIR/data/server.key $WWW/.postgresql/postgresql.key
 /usr/bin/chown -R www:apache  $WWW/.postgresql
fi

/usr/bin/chown -R wadm:apache $ROOT/opt/htdocs/mediawiki-1.13.2
/usr/bin/chown -R www $ROOT/opt/htdocs/mediawiki-1.13.2/config

#%% end
